==> aliyun-python-sdk-emr-2.3.0.tar.gz: aliyun-python-sdk-emr-2.3.0/aliyunsdkemr/request/v20160408/ResetAutoRenewalRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class ResetAutoRenewalRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Emr', '2016-04-08', 'ResetAutoRenewal')

	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_ClusterId(self):
		return self.get_query_params().get('ClusterId')

	def set_ClusterId(self,ClusterId):
		self.add_query_param('ClusterId',ClusterId)

	def get_EcsResetAutoRenewDos(self):
		return self.get_query_params().get('EcsResetAutoRenewDos')

	def set_EcsResetAutoRenewDos(self,EcsResetAutoRenewDos):
		for i in range(len(EcsResetAutoRenewDos)):	
			self.add_query_param('EcsResetAutoRenewDo.' + bytes(i + 1) + '.EcsId' , EcsResetAutoRenewDos[i].get('EcsId'))
			self.add_query_param('EcsResetAutoRenewDo.' + bytes(i + 1) + '.EcsAutoRenew' , EcsResetAutoRenewDos[i].get('EcsAutoRenew'))
			self.add_query_param('EcsResetAutoRenewDo.' + bytes(i + 1) + '.EcsAutoRenewDuration' , EcsResetAutoRenewDos[i].get('EcsAutoRenewDuration'))
			self.add_query_param('EcsResetAutoRenewDo.' + bytes(i + 1) + '.EmrAutoRenew' , EcsResetAutoRenewDos[i].get('EmrAutoRenew'))
			self.add_query_param('EcsResetAutoRenewDo.' + bytes(i + 1) + '.EmrAutoRenewDuration' , EcsResetAutoRenewDos[i].get('EmrAutoRenewDuration'))

==> aliyun-python-sdk-emr-2.3.2.tar.gz: aliyun-python-sdk-emr-2.3.2/aliyunsdkemr/request/v20160408/ResetAutoRenewalRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class ResetAutoRenewalRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Emr', '2016-04-08', 'ResetAutoRenewal')

	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_ClusterId(self):
		return self.get_query_params().get('ClusterId')

	def set_ClusterId(self,ClusterId):
		self.add_query_param('ClusterId',ClusterId)

	def get_EcsResetAutoRenewDos(self):
		return self.get_query_params().get('EcsResetAutoRenewDos')

	def set_EcsResetAutoRenewDos(self,EcsResetAutoRenewDos):
		for i in range(len(EcsResetAutoRenewDos)):	
			self.add_query_param('EcsResetAutoRenewDo.' + str(i + 1) + '.EcsId' , EcsResetAutoRenewDos[i].get('EcsId'))
			self.add_query_param('EcsResetAutoRenewDo.' + str(i + 1) + '.EcsAutoRenew' , EcsResetAutoRenewDos[i].get('EcsAutoRenew'))
			self.add_query_param('EcsResetAutoRenewDo.' + str(i + 1) + '.EcsAutoRenewDuration' , EcsResetAutoRenewDos[i].get('EcsAutoRenewDuration'))
			self.add_query_param('EcsResetAutoRenewDo.' + str(i + 1) + '.EmrAutoRenew' , EcsResetAutoRenewDos[i].get('EmrAutoRenew'))
			self.add_query_param('EcsResetAutoRenewDo.' + str(i + 1) + '.EmrAutoRenewDuration' , EcsResetAutoRenewDos[i].get('EmrAutoRenewDuration'))
